Authors / collaborators
=======================

``nlpsig`` is a `DataSig <https://datasig.ac.uk/>`_ project and written in collaboration with the `Research Engineering Team <https://www.turing.ac.uk/research-engineering>`_ at `The Alan Turing Institute <https://www.turing.ac.uk/>`_.
It was originally written by `Ryan Chan <https://github.com/rchan26>`_ and `Talia Tseriotou <https://github.com/ttseriotou>`_.
Early collaborators to the codebase include `Kasra Hosseini <https://github.com/kasra-hosseini>`_ and `Nathan Simpson <https://github.com/phinate>`_.

For an up-to-date list of collaborators, please see the `GitHub repo <https://github.com/datasig-ac-uk/nlpsig>`_ for this package.
